import React, { useEffect, useState } from "react";
import styled from "styled-components";
import { Grid } from "../Atoms/Grid";
import { GridContainer } from "../Molecules/GridContainer";
import { device } from "../utils/mediaSizes";

interface ITwoColumnLayout {
  title?: string;
  image?: string;
  mobileImage?: string;
  children: React.ReactNode;
  leftFlexBasis: number;
  rightFlexBasis: number;
  headerFontSize?: string;
  mobileHeaderFontSize?: string;
  font?: string;
  imageHeight?: string;
  mobileImageHeight?: string;
  titleColor?: string;
}

interface IStyledHeader {
  headerFontSize?: string;
  mobileHeaderFontSize?: string;
  titleColor?: string;
  font?: string;
}

const StyledHeader = styled.h1<IStyledHeader>`
  text-align: left;
  ${({ headerFontSize }) => headerFontSize && `font-size: ${headerFontSize};`}
  ${({ titleColor }) => titleColor && `color: ${titleColor};`}
  ${({ font }) => font && `font-family ${font};`}
  ${({ mobileHeaderFontSize }) => mobileHeaderFontSize && `font-size: ${mobileHeaderFontSize};`}

  @media ${device.tablet} {
    ${({ headerFontSize }) => headerFontSize && `font-size: ${headerFontSize};`}
  }
`

const StyledImage = styled.img<{ imageHeight: any; mobileImageHeight: any }>`
  ${({ mobileImageHeight }) => mobileImageHeight && `height: ${mobileImageHeight}; width: auto;`}

  @media ${device.tablet} {
    ${({ imageHeight }) => imageHeight && `height: ${imageHeight}; width: auto;`}
  }
`

const StyledTwoColumnLayout = styled.div``;

export const TwoColumnLayout = ({
  title,
  children,
  image,
  leftFlexBasis,
  rightFlexBasis,
  headerFontSize,
  mobileHeaderFontSize,
  mobileImage,
  font,
  imageHeight,
  mobileImageHeight,
  titleColor
}: ITwoColumnLayout) => {
  const [renderedImage, setRenderedImage] = useState(image)
  useEffect(() => {
    if (window.innerWidth < 601) {
      setRenderedImage(mobileImage)
    } else {
      setRenderedImage(image)
    }
  }, [window])

  return (
    <StyledTwoColumnLayout>
      <Grid columns={2} wrap>
        <GridContainer flexBasis={leftFlexBasis} font={font}>
          {title && <StyledHeader headerFontSize={headerFontSize} mobileHeaderFontSize={mobileHeaderFontSize} titleColor={titleColor} font={font}>{title}</StyledHeader>}
          {image && <StyledImage src={renderedImage} imageHeight={imageHeight} mobileImageHeight={mobileImageHeight} alt="image" />}
        </GridContainer>
        <GridContainer flexBasis={rightFlexBasis} font={font}>
          {children}
        </GridContainer>
      </Grid>
    </StyledTwoColumnLayout>
  )
};
